#[repr(C, packed(1))]pub struct ReadLocalSupportedFeaturesParams {
pub page_number: u8,
}Expand description
ReadLocalSupportedFeaturesParams Parameters for Read Local Extended Features command ๐
Fields
page_number: u8Trait Implementations
Sourceimpl ByteAlignedValue for ReadLocalSupportedFeaturesParams
impl ByteAlignedValue for ReadLocalSupportedFeaturesParams
Sourcefn ref_from_hci_bytes(data: &[u8]) -> Result<(&Self, &[u8]), FromHciBytesError>
fn ref_from_hci_bytes(data: &[u8]) -> Result<(&Self, &[u8]), FromHciBytesError>
Obtain a reference to this type from a byte slice. Read more
Sourceimpl Clone for ReadLocalSupportedFeaturesParams
impl Clone for ReadLocalSupportedFeaturesParams
Sourcefn clone(&self) -> ReadLocalSupportedFeaturesParams
fn clone(&self) -> ReadLocalSupportedFeaturesParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) ยท Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl From<ReadLocalSupportedFeaturesParams> for ReadLocalExtendedFeatures
impl From<ReadLocalSupportedFeaturesParams> for ReadLocalExtendedFeatures
Sourcefn from(params: ReadLocalSupportedFeaturesParams) -> Self
fn from(params: ReadLocalSupportedFeaturesParams) -> Self
Converts to this type from the input type.
Sourceimpl<'de> FromHciBytes<'de> for &'de ReadLocalSupportedFeaturesParams
impl<'de> FromHciBytes<'de> for &'de ReadLocalSupportedFeaturesParams
Sourcefn from_hci_bytes(
data: &'de [u8],
) -> Result<(Self, &'de [u8]), FromHciBytesError>
fn from_hci_bytes( data: &'de [u8], ) -> Result<(Self, &'de [u8]), FromHciBytesError>
Deserialize bytes into a HCI type, return additional bytes.
Sourcefn from_hci_bytes_complete(data: &'de [u8]) -> Result<Self, FromHciBytesError>
fn from_hci_bytes_complete(data: &'de [u8]) -> Result<Self, FromHciBytesError>
Deserialize bytes into a HCI type, must consume all bytes.
Sourceimpl Ord for ReadLocalSupportedFeaturesParams
impl Ord for ReadLocalSupportedFeaturesParams
Sourcefn cmp(&self, other: &ReadLocalSupportedFeaturesParams) -> Ordering
fn cmp(&self, other: &ReadLocalSupportedFeaturesParams) -> Ordering
1.21.0 (const: unstable) ยท Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ReadLocalSupportedFeaturesParams
impl PartialEq for ReadLocalSupportedFeaturesParams
Sourcefn eq(&self, other: &ReadLocalSupportedFeaturesParams) -> bool
fn eq(&self, other: &ReadLocalSupportedFeaturesParams) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ReadLocalSupportedFeaturesParams
impl PartialOrd for ReadLocalSupportedFeaturesParams
impl Copy for ReadLocalSupportedFeaturesParams
impl Eq for ReadLocalSupportedFeaturesParams
impl StructuralPartialEq for ReadLocalSupportedFeaturesParams