CommandCompleteWithStatus

Struct CommandCompleteWithStatus 

pub struct CommandCompleteWithStatus<'d> {
    pub num_hci_cmd_pkts: u8,
    pub cmd_opcode: Opcode,
    pub status: Status,
    pub return_param_bytes: RemainingBytes<'d>,
}
Struct representing a command complete event with status

Fields

num_hci_cmd_pkts: u8

Number of packets complete.

cmd_opcode: Opcode

Command opcode.

status: Status

Command status.

return_param_bytes: RemainingBytes<'d>

Return parameters

Implementations

Source

impl CommandCompleteWithStatus<'_>

pub fn handle<C: SyncCmd>(&self) -> Result<C::Handle, FromHciBytesError>

Gets the connection handle associated with the command that has completed.

For commands that return the connection handle provided as a parameter as their first return parameter, this will be valid even if status is an error.

pub fn to_result<C: SyncCmd>(&self) -> Result<C::Return, Error>

Gets a result with the return parameters for C or an Error if status is an error.

Panics

May panic if C::OPCODE is not equal to self.cmd_opcode.

pub fn return_params<C: SyncCmd>(&self) -> Result<C::Return, FromHciBytesError>

Parses the return parameters for C from this event. This may fail if status is an error.

Panics

May panic if C::OPCODE is not equal to self.cmd_opcode.