pub struct CommandCompleteWithStatus<'d> {
pub num_hci_cmd_pkts: u8,
pub cmd_opcode: Opcode,
pub status: Status,
pub return_param_bytes: RemainingBytes<'d>,
}Expand description
Struct representing a command complete event with status
Fields
num_hci_cmd_pkts: u8Number of packets complete.
cmd_opcode: OpcodeCommand opcode.
status: StatusCommand status.
return_param_bytes: RemainingBytes<'d>Return parameters
Implementations
Sourceimpl CommandCompleteWithStatus<'_>
impl CommandCompleteWithStatus<'_>
Sourcepub fn handle<C: SyncCmd>(&self) -> Result<C::Handle, FromHciBytesError>
pub fn handle<C: SyncCmd>(&self) -> Result<C::Handle, FromHciBytesError>
Gets the connection handle associated with the command that has completed.
For commands that return the connection handle provided as a parameter as
their first return parameter, this will be valid even if status is an error.
Sourcepub fn to_result<C: SyncCmd>(&self) -> Result<C::Return, Error>
pub fn to_result<C: SyncCmd>(&self) -> Result<C::Return, Error>
Gets a result with the return parameters for C or an Error if status is
an error.
Panics
May panic if C::OPCODE is not equal to self.cmd_opcode.
Sourcepub fn return_params<C: SyncCmd>(&self) -> Result<C::Return, FromHciBytesError>
pub fn return_params<C: SyncCmd>(&self) -> Result<C::Return, FromHciBytesError>
Parses the return parameters for C from this event. This may fail if status
is an error.
Panics
May panic if C::OPCODE is not equal to self.cmd_opcode.